# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .dict_item import DictItem
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class EquationExtraction(UniversalBaseModel):
    id: str
    name: str
    description: str
    original_format: str
    latex_symbols: typing.List[DictItem]
    narrative_assumptions: typing.List[str]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
